==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/elements/vdxrig.f <==
      SUBROUTINE VDXRIG(NOMTE , XI , RIG ,  NB1 , INDM , INDF )
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 06/04/2004   AUTEUR DURAND C.DURAND 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
      IMPLICIT REAL*8 (A-H,O-Z)
C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------
      CHARACTER*32       JEXNUM , JEXNOM , JEXR8 , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX --------------------
      CHARACTER*16 NOMTE
      INTEGER NB1,NB2,NDDLE,NPGE,NPGSR,NPGSN
      REAL*8 XI(3,9)
      REAL*8 VECTA(9,2,3),VECTN(9,3),VECTPT(9,2,3)
      REAL*8 VECTG(2,3),VECTT(3,3)
      REAL*8 HSFM(3,9),HSS(2,9),HSJ1M(3,9),HSJ1S(2,9)
      REAL*8 BTDM(4,3,42),BTDS(4,2,42)
      REAL*8 HSF(3,9),HSJ1FX(3,9),WGT
      REAL*8 BTDF(3,42),BTILD(5,42),WMATCB(5,42)
      REAL*8 MATC(5,5),KTILD(42,42),RIG(51,51)
      REAL*8 CTOR,EPAIS,KAPPA
      REAL*8 KTILDI(42,42)
      PARAMETER (NPGE=2)
      REAL*8 EPSVAL(NPGE),KSI3S2
      DATA EPSVAL / -0.577350269189626D0,  0.577350269189626D0 /
C
C     RECUPERATION DES OBJETS
C
      CALL JEVETE('&INEL.'//NOMTE(1:8)//'.DESI',' ', LZI )
      NB1  =ZI(LZI-1+1)
      NB2  =ZI(LZI-1+2)
      NPGSR=ZI(LZI-1+3)
      NPGSN=ZI(LZI-1+4)
C
      CALL JEVETE('&INEL.'//NOMTE(1:8)//'.DESR',' ', LZR )
C
      CALL JEVECH ('PCACOQU' , 'L' , JCARA)
      EPAIS = ZR(JCARA)
      KAPPA = ZR(JCARA+3)
      CTOR = ZR(JCARA+4)
C
      NDDLE = 5*NB1+2
C
      CALL VECTAN(NB1,NB2,XI,ZR(LZR),VECTA,VECTN,VECTPT)
C
      DO 5 I=1,NDDLE
      DO 6 J=1,NDDLE
         KTILD(I,J)=0.D0
 6    CONTINUE
 5    CONTINUE
C
      KWGT=0
      DO 100 INTE=1,NPGE
         KSI3S2=EPSVAL(INTE)/2.D0
C
C     CALCUL DE BTDMR, BTDSR : M=MEMBRANE , S=CISAILLEMENT , R=REDUIT
C
      DO 150 INTSR=1,NPGSR
      CALL MAHSMS(0,NB1,XI,KSI3S2,INTSR,ZR(LZR),EPAIS,VECTN,
     &                                       VECTG,VECTT,HSFM,HSS)
C
      CALL HSJ1MS(EPAIS,VECTG,VECTT,HSFM,HSS,HSJ1M,HSJ1S)
C
      CALL BTDMSR(NB1,NB2,KSI3S2,INTSR,ZR(LZR),EPAIS,VECTPT,
     &                                       HSJ1M,HSJ1S,BTDM,BTDS)
 150  CONTINUE
C
C
C---- POUR L ENERGIE DE DEFORMATION DE MEMBRANE PAS DE CISAILLEMENT
C
      IF ( INDM . EQ . 1 ) CALL R8INIR ( 4 * 2 * 42 , 0.D0 , BTDS , 1 )
C
C---- POUR L ENERGIE DE DEFORMATION DE FLEXION
C
      IF ( INDF . EQ . 1 ) THEN 
C
                           CALL R8INIR ( 4 * 3 * 42 , 0.D0 , BTDM , 1 )
C
                           CALL R8INIR ( 4 * 2 * 42 , 0.D0 , BTDS , 1 )
C
      END IF
C
      DO 200 INTSN=1,NPGSN
C
C     CALCUL DE BTDFN : F=FLEXION , N=NORMAL
C     ET DEFINITION DE WGT=PRODUIT DES POIDS ASSOCIES AUX PTS DE GAUSS
C                          (NORMAL) ET DU DETERMINANT DU JACOBIEN
C
      CALL MAHSF(1,NB1,XI,KSI3S2,INTSN,ZR(LZR),EPAIS,VECTN,
     &                                             VECTG,VECTT,HSF)
C
      CALL HSJ1F(INTSN,ZR(LZR),EPAIS,VECTG,VECTT,HSF,
     &                                       KWGT,HSJ1FX,WGT)
C
      CALL BTDFN(1,NB1,NB2,KSI3S2,INTSN,ZR(LZR),EPAIS,VECTPT,HSJ1FX,
     &                                                             BTDF)
C
C     CALCUL DE BTDMN, BTDSN
C     ET
C     FORMATION DE BTILD
C
C
C---- POUR L ENERGIE DE DEFORMATION DE MEMBRANE
C
      IF ( INDM . EQ . 1 ) CALL R8INIR ( 3 * 42 , 0.D0 , BTDF , 1 )
C
C
      CALL BTDMSN(1,NB1,INTSN,NPGSR,ZR(LZR),BTDM,BTDF,BTDS,BTILD)
C
      CALL MATRC(NB2,KAPPA,MATC,VECTT)
C
      CALL R8SCAL(25,WGT,MATC,1)
C
      CALL  BTKB(5,42,NDDLE,MATC,BTILD,WMATCB,KTILDI)
C
      DO 11 I=1,NDDLE
      DO 12 J=1,NDDLE
         KTILD(I,J)=KTILD(I,J)+KTILDI(I,J)
 12   CONTINUE
 11   CONTINUE
C
 200  CONTINUE
 100  CONTINUE
C
C     EXPANSION DE LA MATRICE : AJOUTER DE LA ROTATION FICTIVE
C
         NDDLET=6*NB1+3
         CALL MATRKB(NB1,42,51,NDDLET,KTILD,CTOR,RIG,COEF)
C
C     AFFECTATION DU COEF POUR LA CONTRIBUTION DES ROTATIONS FICTIVES
C     POUR LE CALCUL NON LINEAIRE
C     (CETTE AFFECTATION N'A LIEU QUE DANS LE CAS OU ON PREND LA
C      MATRICE ELASTIQUE AU LIEU DE LA MATRICE TANGENTE)
C
         ZR(LZR-1+1550)=COEF
C
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/elements/vdxrig.f <==
      SUBROUTINE VDXRIG(NOMTE , XI , RIG ,  NB1 , INDM , INDF )
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 16/12/2004   AUTEUR VABHHTS J.PELLET 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
C (AT YOUR OPTION) ANY LATER VERSION.                                 
C
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
C
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
C ======================================================================
      IMPLICIT REAL*8 (A-H,O-Z)
C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------
      CHARACTER*32       JEXNUM , JEXNOM , JEXR8 , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX --------------------
      CHARACTER*16 NOMTE
      INTEGER NB1,NB2,NDDLE,NPGE,NPGSR,NPGSN
      REAL*8 XI(3,9)
      REAL*8 VECTA(9,2,3),VECTN(9,3),VECTPT(9,2,3)
      REAL*8 VECTG(2,3),VECTT(3,3)
      REAL*8 HSFM(3,9),HSS(2,9),HSJ1M(3,9),HSJ1S(2,9)
      REAL*8 BTDM(4,3,42),BTDS(4,2,42)
      REAL*8 HSF(3,9),HSJ1FX(3,9),WGT
      REAL*8 BTDF(3,42),BTILD(5,42),WMATCB(5,42)
      REAL*8 MATC(5,5),KTILD(42,42),RIG(51,51)
      REAL*8 CTOR,EPAIS,KAPPA
      REAL*8 KTILDI(42,42)
      PARAMETER (NPGE=2)
      REAL*8 EPSVAL(NPGE),KSI3S2
      DATA EPSVAL / -0.577350269189626D0,  0.577350269189626D0 /
C
C     RECUPERATION DES OBJETS
C
      CALL JEVETE('&INEL.'//NOMTE(1:8)//'.DESI',' ', LZI )
      NB1  =ZI(LZI-1+1)
      NB2  =ZI(LZI-1+2)
      NPGSR=ZI(LZI-1+3)
      NPGSN=ZI(LZI-1+4)
C
      CALL JEVETE('&INEL.'//NOMTE(1:8)//'.DESR',' ', LZR )
C
      CALL JEVECH ('PCACOQU' , 'L' , JCARA)
      EPAIS = ZR(JCARA)
      KAPPA = ZR(JCARA+3)
      CTOR = ZR(JCARA+4)
C
      NDDLE = 5*NB1+2
C
      CALL VECTAN(NB1,NB2,XI,ZR(LZR),VECTA,VECTN,VECTPT)
C
      DO 5 I=1,NDDLE
      DO 6 J=1,NDDLE
         KTILD(I,J)=0.D0
 6    CONTINUE
 5    CONTINUE
C
      KWGT=0
      DO 100 INTE=1,NPGE
         KSI3S2=EPSVAL(INTE)/2.D0
C
C     CALCUL DE BTDMR, BTDSR : M=MEMBRANE , S=CISAILLEMENT , R=REDUIT
C
      DO 150 INTSR=1,NPGSR
      CALL MAHSMS(0,NB1,XI,KSI3S2,INTSR,ZR(LZR),EPAIS,VECTN,
     &                                       VECTG,VECTT,HSFM,HSS)
C
      CALL HSJ1MS(EPAIS,VECTG,VECTT,HSFM,HSS,HSJ1M,HSJ1S)
C
      CALL BTDMSR(NB1,NB2,KSI3S2,INTSR,ZR(LZR),EPAIS,VECTPT,
     &                                       HSJ1M,HSJ1S,BTDM,BTDS)
 150  CONTINUE
C
C
C---- POUR L ENERGIE DE DEFORMATION DE MEMBRANE PAS DE CISAILLEMENT
C
      IF ( INDM . EQ . 1 ) CALL R8INIR ( 4 * 2 * 42 , 0.D0 , BTDS , 1 )
C
C---- POUR L ENERGIE DE DEFORMATION DE FLEXION
C
      IF ( INDF . EQ . 1 ) THEN 
C
                           CALL R8INIR ( 4 * 3 * 42 , 0.D0 , BTDM , 1 )
C
                           CALL R8INIR ( 4 * 2 * 42 , 0.D0 , BTDS , 1 )
C
      END IF
C
      DO 200 INTSN=1,NPGSN
C
C     CALCUL DE BTDFN : F=FLEXION , N=NORMAL
C     ET DEFINITION DE WGT=PRODUIT DES POIDS ASSOCIES AUX PTS DE GAUSS
C                          (NORMAL) ET DU DETERMINANT DU JACOBIEN
C
      CALL MAHSF(1,NB1,XI,KSI3S2,INTSN,ZR(LZR),EPAIS,VECTN,
     &                                             VECTG,VECTT,HSF)
C
      CALL HSJ1F(INTSN,ZR(LZR),EPAIS,VECTG,VECTT,HSF,
     &                                       KWGT,HSJ1FX,WGT)
C
      CALL BTDFN(1,NB1,NB2,KSI3S2,INTSN,ZR(LZR),EPAIS,VECTPT,HSJ1FX,
     &                                                             BTDF)
C
C     CALCUL DE BTDMN, BTDSN
C     ET
C     FORMATION DE BTILD
C
C
C---- POUR L ENERGIE DE DEFORMATION DE MEMBRANE
C
      IF ( INDM . EQ . 1 ) CALL R8INIR ( 3 * 42 , 0.D0 , BTDF , 1 )
C
C
      CALL BTDMSN(1,NB1,INTSN,NPGSR,ZR(LZR),BTDM,BTDF,BTDS,BTILD)
C
      CALL MATRC(NB2,KAPPA,MATC,VECTT)
C
      CALL DSCAL(25,WGT,MATC,1)
C
      CALL  BTKB(5,42,NDDLE,MATC,BTILD,WMATCB,KTILDI)
C
      DO 11 I=1,NDDLE
      DO 12 J=1,NDDLE
         KTILD(I,J)=KTILD(I,J)+KTILDI(I,J)
 12   CONTINUE
 11   CONTINUE
C
 200  CONTINUE
 100  CONTINUE
C
C     EXPANSION DE LA MATRICE : AJOUTER DE LA ROTATION FICTIVE
C
         NDDLET=6*NB1+3
         CALL MATRKB(NB1,42,51,NDDLET,KTILD,CTOR,RIG,COEF)
C
C     AFFECTATION DU COEF POUR LA CONTRIBUTION DES ROTATIONS FICTIVES
C     POUR LE CALCUL NON LINEAIRE
C     (CETTE AFFECTATION N'A LIEU QUE DANS LE CAS OU ON PREND LA
C      MATRICE ELASTIQUE AU LIEU DE LA MATRICE TANGENTE)
C
         ZR(LZR-1+1550)=COEF
C
      END
